#Change working directory
setwd("...") 

# Plot the Survival Curves for each Civil War Outcome

###############################
# Intervention for Government #
###############################

#####################################
# Government Military Victory Model #
#####################################

GovWin.IntGov.survival <- read.csv("survival_GovWin_IntGov.csv", header=T)

plot(GovWin.IntGov.survival$X_t,GovWin.IntGov.survival$surv_GovWin_IntGov,col="green",type="l",lwd=3)

#####################################
# Opposition Military Victory Model #
#####################################

OppWin.IntGov.survival <- read.csv("survival_OppWin_IntGov.csv", header=T)

plot(OppWin.IntGov.survival$X_t,OppWin.IntGov.survival$surv_OppWin_IntGov,col="red",type="l",lwd=3)

###############################
# Negotiated Settlement Model #
###############################

Negotiate.IntGov.survival <- read.csv("survival_Negotiate_IntGov.csv", header=T)

plot(Negotiate.IntGov.survival$X_t,Negotiate.IntGov.survival$surv_Negotiate_IntGov,col="blue",type="l",lwd=3)

################################################################################
# Full Plot of Intervention for Government across the three Civil War Outcomes #
################################################################################

postscript("IntGov_survival.eps", 
    horizontal=FALSE, onefile=FALSE, width=6, height=6) 
    
plot(GovWin.IntGov.survival$X_t,GovWin.IntGov.survival$surv_GovWin_IntGov,col="black",ylim=c(0,1),xlim=c(1,7396),lty=1,xlab="Duration in Days",ylab="Probability of Survival",type="l",lwd=2,main="Figure 1. Intervention for Government")
lines(OppWin.IntGov.survival$X_t,OppWin.IntGov.survival$surv_OppWin_IntGov,col="black",type="l",lwd=2,lty=2)
lines(Negotiate.IntGov.survival$X_t,Negotiate.IntGov.survival$surv_Negotiate_IntGov,col="black",type="l",lwd=2,lty=3)
box()

leg.txt <- c("Government Military Victory","Opposition Military Victory","Negotiated Settlement")
legend(3000,1,leg.txt,lty=c(1,2,3),col=c("black","black","black"),lwd=c(2,2,2))

dev.off()

###############################
# Intervention for Opposition #
###############################

#####################################
# Government Military Victory Model #
#####################################

GovWin.IntOpp.survival <- read.csv("survival_GovWin_IntOpp.csv", header=T)

plot(GovWin.IntOpp.survival$X_t,GovWin.IntOpp.survival$surv_GovWin_IntOpp,col="green",type="l",lwd=3)

#####################################
# Opposition Military Victory Model #
#####################################

OppWin.IntOpp.survival <- read.csv("survival_OppWin_IntOpp.csv", header=T)

plot(OppWin.IntOpp.survival$X_t,OppWin.IntOpp.survival$surv_OppWin_IntOpp,col="red",type="l",lwd=3)

###############################
# Negotiated Settlement Model #
###############################

Negotiate.IntOpp.survival <- read.csv("survival_Negotiate_IntOpp.csv", header=T)

plot(Negotiate.IntOpp.survival$X_t,Negotiate.IntOpp.survival$surv_Negotiate_IntOpp,col="blue",type="l",lwd=3)

################################################################################
# Full Plot of Intervention for Opposition across the three Civil War Outcomes #
################################################################################

postscript("IntOpp_survival.eps", 
    horizontal=FALSE, onefile=FALSE, width=6, height=6) 
    
plot(GovWin.IntOpp.survival$X_t,GovWin.IntOpp.survival$surv_GovWin_IntOpp,col="black",ylim=c(0,1),lty=1,xlab="Duration in Days",ylab="Probability of Survival",type="l",lwd=2,main="Figure 2. Intervention for Opposition")
lines(OppWin.IntOpp.survival$X_t,OppWin.IntOpp.survival$surv_OppWin_IntOpp,col="black",type="l",lwd=2,lty=2)
lines(Negotiate.IntOpp.survival$X_t,Negotiate.IntOpp.survival$surv_Negotiate_IntOpp,col="black",type="l",lwd=2,lty=3)
box()

leg.txt <- c("Government Military Victory","Opposition Military Victory","Negotiated Settlement")
legend(0,.2,leg.txt,lty=c(1,2,3),col=c("black","black","black"),lwd=c(2,2,2))

dev.off()

#########################
# Balanced Intervention #
#########################

#####################################
# Government Military Victory Model #
#####################################

GovWin.IntBalanced.survival <- read.csv("survival_GovWin_IntBalanced.csv", header=T)

plot(GovWin.IntBalanced.survival$X_t,GovWin.IntBalanced.survival$surv_GovWin_IntBalanced,col="green",type="l",lwd=3)

#####################################
# Opposition Military Victory Model #
#####################################

OppWin.IntBalanced.survival <- read.csv("survival_OppWin_IntBalanced.csv", header=T)

plot(OppWin.IntBalanced.survival$X_t,OppWin.IntBalanced.survival$surv_OppWin_IntBalanced,col="red",type="l",lwd=3)

###############################
# Negotiated Settlement Model #
###############################

Negotiate.IntBalanced.survival <- read.csv("survival_Negotiate_IntBalanced.csv", header=T)

plot(Negotiate.IntBalanced.survival$X_t,Negotiate.IntBalanced.survival$surv_Negotiate_IntBalanced,col="blue",type="l",lwd=3)

###########################################################################
# Full Plot of Balanced Interventions across the three Civil War Outcomes #
###########################################################################

postscript("IntBal_survival.eps", 
    horizontal=FALSE, onefile=FALSE, width=6, height=6) 

plot(GovWin.IntBalanced.survival$X_t,GovWin.IntBalanced.survival$surv_GovWin_IntBalanced,col="black",ylim=c(0,1),lty=1,xlab="Duration in Days",ylab="Probability of Survival",type="l",lwd=2,main="Figure 3. Balanced Intervention")
lines(OppWin.IntBalanced.survival$X_t,OppWin.IntBalanced.survival$surv_OppWin_IntBalanced,col="black",type="l",lwd=2,lty=2)
lines(Negotiate.IntBalanced.survival$X_t,Negotiate.IntBalanced.survival$surv_Negotiate_IntBalanced,col="black",type="l",lwd=2,lty=3)
box()

leg.txt <- c("Government Military Victory","Opposition Military Victory","Negotiated Settlement")
legend(3000,.85,leg.txt,lty=c(1,2,3),col=c("black","black","black"),lwd=c(2,2,2))

dev.off()
